怦然心动 (豆瓣)
Description: 怦然心动电影简介和剧情介绍,怦然心动影评、图片、预告片、影讯、论坛、在线购票
Keywords: 怦然心动,Flipped,怦然心动影评,剧情介绍,电影图片,预告片,影讯,在线购票,论坛

No.25豆瓣电影Top250

# 怦然心动 Flipped (2010)

更新描述或海报

导演: 罗伯·莱纳
编剧: 罗伯·莱纳 / 安德鲁·沙因曼 / 文德琳·范·德拉安南
主演: 玛德琳·卡罗尔 / 卡兰·麦克奥利菲 / 瑞贝卡·德·莫妮 / 安东尼·爱德华兹 / 约翰·马奥尼 / 佩内洛普·安·米勒 / 艾丹·奎因 / 凯文·韦斯曼 / 摩根·莉莉 / 瑞安·克茨纳 / 吉莉安·普法夫 / 迈克尔·博萨 / 博·勒纳 / 杰奎琳·埃沃拉 / 泰勒·格鲁秀斯 / 艾莉·布莱恩特 / 阿什莉·泰勒 / 伊瑟尔·布罗萨德 / 科迪·霍恩 / 迈克尔·博尔顿 / 肖恩·哈珀 / 斯戴芬妮·斯考特 / 帕特丽夏·伦茨 / 马修·戈尔德 / 阿罗拉·凯瑟琳·史密斯 / 凯莉·唐纳利 / 索菲亚·撒高 / 米歇尔·梅斯默 / 斯科特·乔尔·吉兹基 / 罗德·迈尔斯 / 卡拉 帕西托 / 凯特琳·帕西托
类型: 剧情 / 喜剧 / 爱情
官方网站: https://www.warnerbros.com/movies/flipped
制片国家/地区: 美国
语言: 英语
上映日期: 2010-07-26(好莱坞首映) / 2010-09-10(美国)
片长: 90分钟
又名: 萌动青春 / 青春萌动 / 冒失 / 梧桐树之恋
IMDb: tt0817177
豆瓣评分
引用
9.1
1744327人评价
5星
62.2%
4星
30.6%
3星
6.6%
2星
0.5%
1星
0.1%
好友评分
你关注的人看过这部作品的平均分
7.5
4人评价
好于 99% 爱情片
好于 98% 剧情片
想看 看过
评价:
推荐

## 怦然心动的剧情简介 · · · · · ·

布莱斯（卡兰•麦克奥利菲 Callan McAuliffe 饰）全家搬到小镇，邻家女孩朱丽（玛德琳•卡罗尔 Madeline Carroll 饰）前来帮忙。她对他一见钟情，心愿是获得他的吻。两人是同班同学，她一直想方设法接近他，但是他避之不及。她喜欢爬在高高的梧桐树上看风景。但因为施工，树被要被砍掉，她誓死捍卫，希望他并肩作战，但是他退缩了。她的事迹上了报纸，外公对她颇有好感，令他十分困惑。她凭借鸡下蛋的项目获得了科技展第一名，成了全场焦点，令他黯然失色。她把自家鸡蛋送给他，他听家人怀疑她家鸡蛋不卫生，便偷偷把鸡蛋丢掉。她得知真相，很伤心，两人关系跌入冰点。她跟家人诉说，引发争吵。原来父亲一直攒钱照顾傻弟弟，所以生活拮据。她理解了父母，自己动手，还得到了他外公的鼎力相助。他向她道歉，但是并未解决问题。他开始关注她。鸡蛋风波未平，家庭晚宴与午餐男孩评选... (展开全部) 布莱斯（卡兰•麦克奥利菲 Callan McAuliffe 饰）全家搬到小镇，邻家女孩朱丽（玛德琳•卡罗尔 Madeline Carroll 饰）前来帮忙。她对他一见钟情，心愿是获得他的吻。两人是同班同学，她一直想方设法接近他，但是他避之不及。她喜欢爬在高高的梧桐树上看风景。但因为施工，树被要被砍掉，她誓死捍卫，希望他并肩作战，但是他退缩了。她的事迹上了报纸，外公对她颇有好感，令他十分困惑。她凭借鸡下蛋的项目获得了科技展第一名，成了全场焦点，令他黯然失色。她把自家鸡蛋送给他，他听家人怀疑她家鸡蛋不卫生，便偷偷把鸡蛋丢掉。她得知真相，很伤心，两人关系跌入冰点。她跟家人诉说，引发争吵。原来父亲一直攒钱照顾傻弟弟，所以生活拮据。她理解了父母，自己动手，还得到了他外公的鼎力相助。他向她道歉，但是并未解决问题。他开始关注她。鸡蛋风波未平，家庭晚宴与午餐男孩评选又把两人扯在了一起…… ©豆瓣

## 怦然心动的演职员 · · · · · · ( 全部 36 )

- 罗伯·莱纳 导演
- 玛德琳·卡罗尔 饰 朱丽·巴克 Juli Baker
- 卡兰·麦克奥利菲 饰 布莱斯·罗斯基 Bryce Loski
- 瑞贝卡·德·莫妮 饰 帕齐·罗斯基 Patsy Loski
- 安东尼·爱德华兹 饰 斯蒂文·罗斯基 Steven Loski
- 约翰·马奥尼 饰 切特·邓肯 Chet Duncan

## 怦然心动的视频和图片 · · · · · · ( 预告片1 | 添加视频评论 | 图片1093 · 添加 )

## 怦然心动的获奖情况 · · · · · · ( 全部 )

- 第6届豆瓣电影年度榜单
- 2010s电影(提名)

## 喜欢这部电影的人也喜欢 · · · · · ·

  罗马假日

  泰坦尼克号

  爱在黎明破晓前

  恋恋笔记本

  重庆森林

  傲慢与偏见

  天使爱美丽

  爱乐之城

  情书

  剪刀手爱德华

我要写短评

## 怦然心动的短评 · · · · · · ( 全部 409843 条 )

热门 / 最新 / 好友

### 16339 有用 鹿 卡 看过 2010-11-28 22:39:46

外公说的话：有些人浅薄，有些人金玉其外败絮其中，但是总有一天，你会遇到一个绚丽的人，她让你觉得你以前遇到过的所有人都只是浮云。片尾曲Everly brothers的Let it be me很好听。

### 12953 有用 胡克 看过 2010-12-07 00:25:43

某山渣树怎么好意思说自己是史上最纯？？！！！！！ 这个真打动我了。。。女孩是第二眼美女！！！！！！！！！！

### 5829 有用 不流ᝰ 看过 2010-12-18 12:27:04

上学的时候早恋，父母反对；上班了不恋爱，父母反对。你真是羡慕人家老外啊。

### 14422 有用 图灵莉莎 看过 2010-12-02 10:41:07

我看完后也对这女孩感触特别深，她独立而勤劳，恪守自尊但又不敏感到浑身长刺，正像邦妮另外一条说的，没有那个男孩，她也会生长得很好。对于成长电影来说，它对孩子和家长都很有教育意义，不论面对挫折还是爱，它都有非常正向的可贵的价值观。

### 4894 有用 ❤yone.小米 看过 2010-11-28 21:09:59

篮子男孩，好萌的活动，怎么我们学校以前没有啊！

> 更多短评 409843条
为什么被折叠？ 有一些短评被折叠了
评论被折叠，是因为发布这条评论的帐号行为异常。评论仍可以被展开阅读，对发布人的账号不造成其他影响。如果认为有问题，可以联系豆瓣电影。

### 0 有用 CoCo陶可可 看过 2021-02-09 21:19:06

2021，004。结局很甜，爷爷很好

### 0 有用 LLudeer 看过 2013-10-08 17:15:00

老外好早熟，女主好眼熟。

我要写影评

## 怦然心动的影评 · · · · · · ( 全部 7241 条 )

热门 / 最新 / 好友
柏邦妮 2010-12-01 17:42:09

## 怦然，但是不仅仅是心动

一连看了两遍《怦然心动》，真的是怦然心动。一对小孩，一棵树，特别简单的故事，讲得荡气回肠。我感触最深的一点是：女生十来岁就有超脱的自省意识，审视自己爱的人到底值不值得爱。一旦触及她的自尊，立刻决定放弃这个男生。我们文化里的“爱”，似乎都要低到尘埃里，舍弃自... (展开)
26903 708 1348回应 收起
福鹿 2010-12-10 17:41:43

## 当你遇到那个人

听过一句话：我一直相信，这个世界上是有一些爱情如同宿命般无从逃避，不可取代，色授魂予，需以性命相拼。 前几天听我的母亲讲起她的初恋，无非是一个又高又帅气的男人从无数追求者中脱颖而出，无微不至地体贴和追求，抄情诗，写情书云云。 可是造化弄人，他们终没能在一起。... (展开)
6030 378 474回应 收起
艾小柯 2010-12-12 20:02:53

## 谁能不心动

根据儿童作家文德琳•范•德拉安南2001年的小说《怦然心动》（Flipped）改编的同名电影中的女主人公朱莉是个非常与众不同的小女生。这家伙7岁就开始准备恋爱了，缠着新搬来的邻家男孩布莱斯不放，举止大胆热烈，直吓得布莱斯躲她如躲瘟神。布莱斯的老爸也不喜欢朱莉，更看... (展开)
4898 274 238回应 收起
小宇宙 2011-04-25 15:07:10

## 《怦然心动》经典台词（中、英）

A painting is more than the sum of its parts. A cow by itself is just a cow. A meadow by itself is just grass, flowers. And the sun peeking through the trees is just a beam of light. But you put them all together and it can be magic. 一幅画不是众多物件简单... (展开)
4587 77 138回应 收起
Delphi 2010-11-13 21:22:10

## Let it be the one merits you(剧透)

这篇影评可能有剧透

看完电影，听完第一片尾曲《let it be me》，外面是不变的黑暗，玻璃窗面反射微弱的自己。 我认为这是一个遥远的春暮，那棵高高的树，围绕着落日聚合的远去的云朵，无疑是小女孩美丽心灵的映衬。然而只讨论映衬，难免失之庸俗和狭隘，不过当你看到一个八年级的小女孩爬上一棵傲... (展开)
1439 81 109回应 收起
达达 2018-08-11 22:01:06 #《怦然心动》有哪些细节打动了你？

## 《怦然心动》有哪些细节打动了你？

这篇影评可能有剧透

记不清是第几次看这部电影了，一直没有想起来写影评。最近又重新看了一次，大概算是读懂了这部豆瓣排名25的纯爱电影吧，想记录下现阶段我所理解的爱情，这是我写这篇影评的初衷。 我一直对爱情没有特别深的感悟，从小到大，我最重视的是友情和亲情，这部电影对我的影响很大，因... (展开)
1315 8 60回应 收起
Deli-cat 2010-11-28 18:09:10

## 电影和书一样让人flipped

书我看了好多遍，电影也很喜欢。 一是因为导演和编剧非常尊重原著，julianna 和bryce的独白基本和原著是一样的，我最喜欢chet外公的那段话,大致是some people are dip in flat, some in satin, some in glossy, but someday if you find someone who is iridescent, it'll nev... (展开)
489 35 175回应 收起
wangyi 2010-08-08 15:14:47

## 翻

当我走出电影院的时候,有一个60左右的老太太对她旁边的人说:"It reminds me my boy friend at high school." 这是部清淡到有些日本风的电影,内容和经典台词基本靠看TRAILER就能了解了.我喜欢它柔和的画面,简单清新的音乐. 在很小的时候,喜欢一个人就是自我纠结着,沉浸在自己的... (展开)
506 81 115回应 收起
辰凌 2011-04-21 20:29:47

## 疲惫生活的英雄梦想

“爱之于我，不是肌肤之亲，不是一蔬一饭。它是一种不死的欲望，是疲惫生活中的英雄梦想。” ——杜拉斯 《怦然心动》。看到自己喜欢的编剧柏邦妮极力推崇。看罢发现果然所言非虚，欣然怂恿身边的朋友去看。海报是一对小... (展开)
616 19 39回应 收起

> 更多影评 7241篇

添加新讨论

## 讨论区 · · · · · ·

谁解释一下。这电影到底哪里好看？ | 来自泥水 | 251 回应 | 2022-11-24 20:28:52
“禁止早恋”是中国特色 | 来自den86705 | 18 回应 | 2022-11-24 00:43:46
旁白毁了整部片子 | 来自风柜跑来的人 | 206 回应 | 2022-11-24 00:32:38
谁能给我推荐点类似的小说或者片子。。 | 来自Anthea_ |  | 2022-11-22 21:46:22
有人和我一样看完怦然心动哭的吗… | 来自大迈 | 24 回应 | 2022-11-20 22:37:52

> 去这部影片的讨论区（全部732条）

## 关于《怦然心动》的问题 · · · · · · ( 全部36个 )

- Bryce的爸爸是否很向往Baker一家的生活？ 15人回答
- 美国现在孩子们的毕业礼还有basketboys这样的活动吗？ 10人回答

> 全部36个问题

## 在哪儿看这部电影 · · · · · ·

报错

- 爱奇艺视频 VIP免费观看
- 腾讯视频 VIP免费观看
- 哔哩哔哩 VIP免费观看

## 本片原声正在播放 · · · · · ·

去豆瓣音乐收听

## 以下片单推荐 · · · · · · ( 全部 )

- ★豆瓣高分电影榜★ （上）9.7-8.6分 (影志)
- 【容易忽视的好电影】 (影志)
- 那些牛叉闪闪的片子 (家庭种菜笔记)
- 电影中的美少年 (海棠一生)
- 同时入选IMDB250和豆瓣电影250的电影 (东方快车)

## 谁在看这部电影 · · · · · ·

- 峰峰
  2分钟前 想看
- 笑尽往事
  3分钟前 看过
- spair
  4分钟前 看过

3180912人看过 / 421376人想看

订阅怦然心动的评论:
feed: rss 2.0